# NOMAD-CAMELS Driver for SwabianInstruments TimeTagger

Driver for the TimeTagger by SwabianInstruments written for the measurement software [NOMAD-CAMELS](https://fau-lap.github.io/NOMAD-CAMELS/).


## Installation
To use this driver, you need the [TimeTagger software from SwabianInstruments](https://www.swabianinstruments.com/static/documentation/TimeTagger/sections/installation.html).  
After the installation, if the driver does not yet work, locate the files "TimeTagger.py", "_TimeTagger.h" and "_TimeTagger.cxx" and copy them into the driver's directory.

## Features
Currently supported measurement types are Countrate, Correlation and Count-Between-Markers.


## Documentation

For more information visit the [documentation](https://fau-lap.github.io/NOMAD-CAMELS/doc/instruments/instruments.html).


## Changelog
### 0.1.1
Fixes:
- Several issues with configuration were fixed


